@@ -126,6 +126,7 @@ from google.cloud.container_v1.types.cluster_service import (
     NotificationConfig,
     Operation,
     OperationProgress,
+    PodCIDROverprovisionConfig,
     PrivateClusterConfig,
     PrivateClusterMasterGlobalAccessConfig,
     PrivateIPv6GoogleAccess,
@@ -274,6 +275,7 @@ __all__ = (
     "NotificationConfig",
     "Operation",
     "OperationProgress",
+    "PodCIDROverprovisionConfig",
     "PrivateClusterConfig",
     "PrivateClusterMasterGlobalAccessConfig",
     "RecurringTimeWindow",
