@@ -121,6 +121,7 @@ from .types.cluster_service import (
     NotificationConfig,
     Operation,
     OperationProgress,
+    PodCIDROverprovisionConfig,
     PrivateClusterConfig,
     PrivateClusterMasterGlobalAccessConfig,
     PrivateIPv6GoogleAccess,
@@ -272,6 +273,7 @@ __all__ = (
     "NotificationConfig",
     "Operation",
     "OperationProgress",
+    "PodCIDROverprovisionConfig",
     "PrivateClusterConfig",
     "PrivateClusterMasterGlobalAccessConfig",
     "PrivateIPv6GoogleAccess",
