@@ -128,6 +128,7 @@ from .types.cluster_service import (
     NotificationConfig,
     Operation,
     OperationProgress,
+    PodCIDROverprovisionConfig,
     PodSecurityPolicyConfig,
     PrivateClusterConfig,
     PrivateClusterMasterGlobalAccessConfig,
@@ -293,6 +294,7 @@ __all__ = (
     "NotificationConfig",
     "Operation",
     "OperationProgress",
+    "PodCIDROverprovisionConfig",
     "PodSecurityPolicyConfig",
     "PrivateClusterConfig",
     "PrivateClusterMasterGlobalAccessConfig",
