@@ -122,6 +122,7 @@ from .cluster_service import (
     NotificationConfig,
     Operation,
     OperationProgress,
+    PodCIDROverprovisionConfig,
     PodSecurityPolicyConfig,
     PrivateClusterConfig,
     PrivateClusterMasterGlobalAccessConfig,
@@ -283,6 +284,7 @@ __all__ = (
     "NotificationConfig",
     "Operation",
     "OperationProgress",
+    "PodCIDROverprovisionConfig",
     "PodSecurityPolicyConfig",
     "PrivateClusterConfig",
     "PrivateClusterMasterGlobalAccessConfig",
